-- About GOBI.lua
-- IDS Project, Mark Sullivan, sullivm@geneseo.edu
-- GOBI.lua does an GOBI search for the ISBN or Title for loans.
-- scriptActive must be set to true for the script to run.
--


local settings = {};
settings.scriptActive = GetSetting("Active");
settings.account= GetSetting("Account");
settings.Email= GetSetting("Email");
settings.password= GetSetting("Password");

local interfaceMngr = nil;
local GOBISearchForm = {};
GOBISearchForm.Form = nil;
GOBISearchForm.Browser = nil;
GOBISearchForm.RibbonPage = nil;

require "Atlas.AtlasHelpers";

function Init()
	if settings.scriptActive then
		if GetFieldValue("Transaction", "RequestType") == "Loan" then
 			interfaceMngr = GetInterfaceManager();
			--Create Form
			GOBISearchForm.Form = interfaceMngr:CreateForm("GOBI", "Script");
			 -- Create browser
			GOBISearchForm.Browser = GOBISearchForm.Form:CreateBrowser("GOBI Search", "GOBI Search Browser", "GOBI Search");
			-- Hide the text label
			GOBISearchForm.Browser.TextVisible = false;
	
			-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
			GOBISearchForm.RibbonPage = GOBISearchForm.Form:GetRibbonPage("GOBI Search");
			-- Imports price from first Item in list.  
			GOBISearchForm.RibbonPage:CreateButton("Search ISBN", GetClientImage("Search32"), "SearchISBN", "GOBI Search");
			GOBISearchForm.RibbonPage:CreateButton("Search Title", GetClientImage("Search32"), "SearchTitle", "GOBI Search");
			GOBISearchForm.RibbonPage:CreateButton("Import Price", GetClientImage("Search32"), "PullPrice", "GOBI Search");
           
			GOBISearchForm.Form:Show();
            
			Search();
		end
	end
end

function Search()
	GOBISearchForm.Browser:RegisterPageHandler("formExists", "loginForm", "GOBILoaded", false);
	GOBISearchForm.Browser:Navigate("http://www.gobi3.com/Pages/Login.aspx");	
end

function GOBILoaded()
	GOBISearchForm.Browser:SetFormValue("loginForm", "guser", settings.Email);
	GOBISearchForm.Browser:SetFormValue("loginForm", "gpword", settings.password);
	GOBISearchForm.Browser:SubmitForm("loginForm");
	GOBISearchForm.Browser:RegisterPageHandler("formExists", "basicsearchform", "StartSearch", false);
  
end

function loadStandardSearch()
  GOBISearchForm.Browser:RegisterPageHandler("formExists", "frmMain", "StartSearch", false);
  GOBISearchForm.Browser:Navigate("http://www.gobi3.com/hx/gobi.ashx?location=searchstandardparms");
end


function StartSearch()
	local isXn = GetFieldValue("Transaction", "ISSN");
	if isXn:len()<8 then
		SearchTitle()
	else
		SearchISBN()
	end
end

function SearchISBN()
	GOBISearchForm.Browser:SetFormValue("basicsearchform", "basicsearchinputtype", "Isbn");
    GOBISearchForm.Browser:SetFormValue("basicsearchform", "basicsearchinput", GetFieldValue("Transaction", "ISSN"));
	GOBISearchForm.Browser:ClickObject("basicsearchsubmit");
end

function SearchTitle()
	GOBISearchForm.Browser:SetFormValue("basicsearchform", "basicsearchinputtype", "Title");
	GOBISearchForm.Browser:SetFormValue("basicsearchform", "basicsearchinputmode", "AdvancedAll");
    GOBISearchForm.Browser:SetFormValue("basicsearchform", "basicsearchinput", GetFieldValue("Transaction", "LoanTitle"));
	GOBISearchForm.Browser:ClickObject("basicsearchsubmit");
end

function PullPrice()
  local spanElements = GOBISearchForm.Browser.WebBrowser.Document:GetElementsByTagName("span");
  if spanElements == nil then
    return false;
  end
  
  local testSpan = false;
  for i=0, spanElements.Count - 1 do
    local spanElement = GOBISearchForm.Browser:GetElementByCollectionIndex(spanElements, i);
    local priceText = spanElement.InnerText;
    if priceText ~= nil then
      if testSpan then
        local spanElement = GOBISearchForm.Browser:GetElementByCollectionIndex(spanElements, i);
        local priceText = spanElement.InnerText;
        SetFieldValue("Transaction", "MaxCost", priceText);
        ExecuteCommand("SwitchTab", {"Detail"});
        return;
      end

      if string.find (priceText,"US List")~=nil then
        if string.find (priceText,"USD")==nil then
          testSpan= true
        end
      end
    end
  end
end
